@@ -67,7 +67,7 @@ def client2():
 @pytest.fixture
 def client3():
     import AppFact as af
-    with af.create_app().test_client() as c:
+    with af.create_app(FSA_DEBUG=False, FSA_LOGGING_LEVEL=logging.DEBUG).test_client() as c:
         yield c
 
 @pytest.fixture
@@ -157,7 +157,7 @@ def all_auth(client, user, pswd, check, *args, **kwargs):
 def test_perms(client):
     check(200, client.get("/any"))  # open route
     check(401, client.get("/login"))  # login without login
-    check(401, client.get("/"))  # empty path
+    check(404, client.get("/"))  # empty path
     # admin only
     check(401, client.get("/admin"))
     log.debug(f"App.user_in_group: {App.user_in_group}")
@@ -189,11 +189,11 @@ def test_perms(client):
     all_auth(client, "hobbes", App.UP["hobbes"], check_200, "/read")
 
 def test_whatever(client):
-    check(401, client.get("/whatever"))
-    check(401, client.post("/whatever"))
-    check(401, client.put("/whatever"))
-    check(401, client.patch("/whatever"))
-    check(401, client.delete("/whatever"))
+    check(404, client.get("/whatever"))
+    check(404, client.post("/whatever"))
+    check(404, client.put("/whatever"))
+    check(404, client.patch("/whatever"))
+    check(404, client.delete("/whatever"))
     push_auth(app._fsa, "fake")
     check(404, client.get("/whatever", data={"LOGIN": "dad"}))
     check(404, client.post("/whatever", data={"LOGIN": "dad"}))
@@ -230,8 +230,8 @@ def test_fsa_token():
     try:
         user = app._fsa._get_any_token_auth("R:U:demain:signature")
         assert False, "expecting a bad timestamp format"
-    except Exception as e:
-        assert "unexpected timestamp format" in str(e)
+    except fsa.FSAException as e:
+        assert "unexpected timestamp format" in e.message
     # force expiration
     grace = app._fsa._grace
     app._fsa._grace = -1000000
@@ -373,12 +373,6 @@ def test_authorize():
     app._fsa._user = "hobbes"
     res = stuff()
     assert res.status_code == 403
-    # FIXME
-    # mode, app._fsa._mode = app._fsa._mode, "always"
-    # app._fsa._user = None
-    # res = stuff()
-    # assert res.status_code == 401
-    # app._fsa._mode = mode
     try:
         @app._fsa._group_auth("stuff", fsa.ALL, fsa.ANY)
         def foo():
@@ -494,15 +488,9 @@ def test_params(client):
     assert res.data == b"su world"
 
 def test_missing(client):
-    saved, app._fsa._check = app._fsa._check, True
     check(403, client.get("/mis1"))
     check(403, client.get("/mis2"))
     check(403, client.get("/empty", data={"LOGIN": "dad"}))
-    app._fsa._check = False
-    # check(200, client.get("/mis1"))
-    # check(200, client.get("/mis2"))
-    check(403, client.get("/empty", data={"LOGIN": "dad"}))
-    app._fsa._check = saved
 
 def test_nogo(client):
     check(403, client.get("/nogo"))
@@ -567,7 +555,7 @@ def test_custom(client):
     assert b"my_int: 5432" in res.data
 
 def test_appext(client2):
-    check(401, client2.get("/bad"))
+    check(500, client2.get("/bad"))
     check(500, client2.get("/bad", data={"LOGIN": "dad"}))
     check(401, client2.get("/stuff"))
     res = check(200, client2.get("/stuff", data={"LOGIN": "dad"}))
@@ -577,7 +565,7 @@ def test_appext(client2):
     check(500, client2.get("/bad"))
     client2.cookie_jar.clear()
     check(401, client2.get("/stuff"))
-    check(401, client2.get("/bad"))
+    check(500, client2.get("/bad"))
 
 def test_blueprint(client):
     check(401, client.get("/b1/words/foo"))
@@ -610,7 +598,7 @@ def test_appfact(client3):
     check(400, client3.get("/add", data={"i": "sept", "j": "deux", "LOGIN": "dad"}))
     check(400, client3.get("/add", data={"i": "7", "LOGIN": "dad"}))
     # blueprint
-    check(401, client3.get("/b/word/fun"))
+    check(404, client3.get("/b/word/fun"))
     res = check(200, client3.get("/b/words/fun", data={"LOGIN": "dad"}))
     assert res.data == b"fun"
     res = check(200, client3.get("/b/words/bin", data={"LOGIN": "dad", "n": "2"}))
@@ -640,15 +628,16 @@ def test_something_3(client3):
     res = check(200, client3.get("/b/something", data={"LOGIN": "dad"}))
     assert res.data == b"CALVIN"
 
-def test_401_redirect(client):
-    app._fsa._401_redirect = "/login-page"
-    res = check(307, client.get("/auth/fake"))
-    assert "/login-page" in res.location
-    app._fsa._url_name = "URL"
-    res = check(307, client.get("/auth/fake"))
-    assert "/login-page" in res.location and "URL" in res.location and "fake" in res.location
-    app._fsa._401_redirect = None
-    app._fsa._url_name = None
+def test_401_redirect():
+    import AppFact as af
+    app = af.create_app(FSA_401_REDIRECT="/login-page")
+    with app.test_client() as client:
+        res = check(307, client.get("/something"))
+        assert "/login-page" in res.location
+        app._fsa._url_name = "URL"
+        res = check(307, client.get("/something"))
+        assert "/login-page" in res.location and "URL" in res.location and "something" in res.location
+        res = check(200, client.get("/something", data={"LOGIN": "dad"}))
 
 def test_path(client):
     res = check(200, client.get("/path/foo"))
@@ -664,14 +653,15 @@ def test_reference():
     v1, v2 = "hello!", "world!"
     r1 = fsa.Reference()
     r1.set(v1)
-    assert r1 == v1
+    assert r1 == v1 and not r1 != v1
+    assert r1.startswith("hell")
     r2 = fsa.Reference(set_name="set_object")
     r2.set_object(v2)
     assert r2 == v2
+    assert r2.endswith("ld!")
     r3 = fsa.Reference("1")
     assert r3 == "1" and r3 != "one"
-    assert "0" < r3 and "1" <= r3 and "2" > r3 and "1" >= r3
-    assert "1".__hash__() == r3.__hash__()
+    assert r3.isdigit()
     assert repr("1") == repr(r3)
 
 def test_www_authenticate(client):
@@ -746,8 +736,6 @@ def test_http_token():
         pop_auth(app._fsa)
 
 def test_per_route(client):
-    mode, app._fsa._mode = app._fsa._mode, "lazy"
-    log.debug(f"mode switched from {mode} to lazy")
     # data for 4 various authentication schemes
     from requests.auth import _basic_auth_str as basic_auth
     BASIC = {"Authorization": basic_auth("calvin", App.UP["calvin"])}
@@ -798,8 +786,6 @@ def test_per_route(client):
     check(200, client.get("/auth/ftp", data=PARAM))
     check(200, client.get("/auth/ftp", json=PARAM))
     check(401, client.get("/auth/ftp", headers=BASIC))
-    # cleanup
-    app._fsa._mode = mode
 
 def test_bad_app():
     from AppBad import create_app
@@ -984,7 +970,7 @@ def test_object_perms_errors():
         else:
             return True
     # triggers an overwrite warning
-    app.register_object_perms("known", is_okay)
+    app.object_perms("known", is_okay)
     # declaration time errors
     try:
         @app.get("/bad-perm-1", authorize=tuple())
@@ -1200,7 +1186,18 @@ def test_warnings_and_errors():
     @app.cast("foo")
     def cast_foo(s: str):
         return s
-    fsa.register_cast("foo", cast_foo)
+    app.cast("foo", cast_foo)
+    # type errors
+    try:
+        app = af.create_app(FSA_CAST="not a dict")
+        assert False, "should not get through"
+    except Exception as e:
+        assert "FSA_CAST must be a dict" in str(e)
+    try:
+        app = af.create_app(FSA_OBJECT_PERMS="should be a dict")
+        assert False, "should not get through"
+    except Exception as e:
+        assert "FSA_OBJECT_PERMS must be a dict" in str(e)
 
 def test_jsondata(client):
     # simple types, anything but strings
